@@ -10,6 +10,7 @@ from DateTime import DateTime
 from plone.app.querystring import queryparser
 from collective.media.interfaces import ICanContainMedia
 import re
+import time
 
 try:
     from Products.PloneGetPaid.interfaces import IBuyableMarker
@@ -22,6 +23,45 @@ class CommonBrowserView(BrowserView):
     """
     Common utilities for all the other views
     """
+    nxt = None
+    prv = None
+    
+    def cacheNextPrev(self):
+        """
+        Caches the values for next and prev
+        """
+        catalog = getToolByName(self.context, 'portal_catalog')
+        results = catalog.queryCatalog({"portal_type": "Media Event",
+                                 "sort_on": "start",
+                                 "hasMedia": True,
+                                 "review_state": "published"})
+        
+        for i in range(0, len(results)):
+            if results[i].UID == self.context.UID():
+                if i < len(results) - 2:
+                    self.nxt = results[i +1]
+    
+                if i > 0:
+                    self.prv = results[i -1]
+    
+    def getNextEvent(self):
+        """
+        Gets the next event in chronological order.
+        """
+        if self.nxt is None:
+            self.cacheNextPrev()
+        
+        return self.nxt
+    
+    def getPrevEvent(self):
+        """
+        Gets the previous event in chronological order
+        """
+        if self.prv is None:
+            self.cacheNextPrev()
+        
+        return self.prv
+    
     def slideshow(self, parent):
         """
         Creates a slideshow with the media from parent
@@ -116,13 +156,59 @@ class CommonBrowserView(BrowserView):
             return "%s %s"%(names[1], names[0])
         else:
             return person
+          
+    def isEventPast(self, event):
+        """
+        Checks if the event is already past
+        """
+        if event.portal_type != 'Event' and event.portal_type != 'Media Event':
+            return False
+        else:
+            return event.end() < time.time()
+    
+    def getFormattedEventDate(self, event):
+        """
+        Formats the start and end dates properly and marks the event as past or future
+        """
+        if event.portal_type != 'Event' and event.portal_type != 'Media Event':
+            return ""
+        
+        samedate = event.start().strftime('%d - %m - %Y') == event.end().strftime('%d - %m - %Y')
+        finalDatesFmt = '<div class="dates %(class)s"><span class="dateText">%(dates)s %(hours)s</span></div>'
+        
+        dates = "%s"%(samedate and event.start().strftime('%A, %d %B %Y') or "%s to %s"%(event.start().strftime('%A, %d %B %Y'), event.end().strftime('%A, %d %B %Y')))
+        
+        openingHour = event.start().strftime('%H:%M')
+        closingHour = event.end().strftime('%H:%M')
+        hoursExist = openingHour != closingHour
+        
+        hours = hoursExist and ', <span class="hours">%s to %s</span>'%(openingHour, closingHour) or ''
+        
+        finalDates = finalDatesFmt%{'class': self.isEventPast(event) and 'past' or 'future', 'dates': dates, 'hours': hours}
+        
+        return finalDates
             
     def isBuyable(self, item):
+        """
+        Check if an item is buyable with PloneGetPaid
+        """
         if not GETPAID_EXISTS:
             return False
         else:
             return IBuyableMarker.providedBy(item)
-            
+    
+    def getEventBookingLink(self, event):
+        """
+        Check if the booking information is a link or just a code. return a full url
+        """
+        if not event.getBooking():
+            return ""
+        else:
+            if event.getLink().find("http://") != -1:
+                return event.getLink()
+            else:
+                return 'http://purchase.tickets.com/buy/TicketPurchase?agency=ARNOLFINI&organ_val=26385&schedule=list&event_val=%s'%event.getLink()
+      
     def _uniq(self, alist):    # Fastest order preserving
         set = {}
         return [set.setdefault(e,e) for e in alist if e not in set]
@@ -136,44 +222,6 @@ class EventView(CommonBrowserView):
     """'
      Override of media event view class.
     """
-    nxt = None
-    prv = None
-    
-    def cacheNextPrev(self):
-        """
-        Caches the values for next and prev
-        """
-        catalog = getToolByName(self.context, 'portal_catalog')
-        results = catalog.queryCatalog({"portal_type": "Media Event",
-                                 "sort_on": "start",
-                                 "hasMedia": True,
-                                 "review_state": "published"})
-        
-        for i in range(0, len(results)):
-            if results[i].UID == self.context.UID():
-                if i < len(results) - 2:
-                    self.nxt = results[i +1]
-    
-                if i > 0:
-                    self.prv = results[i -1]
-    
-    def getNextEvent(self):
-        """
-        Gets the next event in chronological order.
-        """
-        if self.nxt is None:
-            self.cacheNextPrev()
-        
-        return self.nxt
-    
-    def getPrevEvent(self):
-        """
-        Gets the previous event in chronological order
-        """
-        if self.prv is None:
-            self.cacheNextPrev()
-        
-        return self.prv
         
     
 class EventArchiveView(EventView):
